@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: zcml.py 97301 2009-02-26 14:10:08Z nadako $
+$Id: zcml.py 98086 2009-03-14 09:56:58Z icemac $
 """
 __docformat__ = "reStructuredText"
 
@@ -40,9 +40,8 @@ class ITemplateDirective(zope.interface.Interface):
         )
 
     name = zope.schema.TextLine(
-        title=u"The name of the pagelet.",
-        description=u"The name is used in the IController to look up the "
-                      "pagelet.",
+        title=u"The name of the template.",
+        description=u"The name is used to look up the template.",
         default=u'',
         required=False)
 
